@@ -16,8 +16,24 @@ package hugolib
 import (
 	"bytes"
 	"context"
+	"encoding/json"
 	"fmt"
+	"os"
+	"path/filepath"
 	"runtime/trace"
+	"strings"
+
+	"github.com/gohugoio/hugo/publisher"
+
+	"github.com/gohugoio/hugo/hugofs"
+
+	"github.com/gohugoio/hugo/common/para"
+	"github.com/gohugoio/hugo/config"
+	"github.com/gohugoio/hugo/resources/postpub"
+
+	"github.com/spf13/afero"
+
+	"github.com/gohugoio/hugo/resources/resource"
 
 	"github.com/gohugoio/hugo/output"
 
@@ -136,15 +152,18 @@ func (h *HugoSites) Build(config BuildCfg, events ...fsnotify.Event) error {
 		if err != nil {
 			h.SendError(err)
 		}
+
+		if err = h.postProcess(); err != nil {
+			h.SendError(err)
+		}
 	}
 
 	if h.Metrics != nil {
 		var b bytes.Buffer
 		h.Metrics.WriteMetrics(&b)
 
-		h.Log.FEEDBACK.Printf("\nTemplate Metrics:\n\n")
-		h.Log.FEEDBACK.Print(b.String())
-		h.Log.FEEDBACK.Println()
+		h.Log.Printf("\nTemplate Metrics:\n\n")
+		h.Log.Println(b.String())
 	}
 
 	select {
@@ -163,7 +182,7 @@ func (h *HugoSites) Build(config BuildCfg, events ...fsnotify.Event) error {
 		return err
 	}
 
-	errorCount := h.Log.ErrorCounter.Count()
+	errorCount := h.Log.LogCounters().ErrorCounter.Count()
 	if errorCount > 0 {
 		return fmt.Errorf("logged %d error(s)", errorCount)
 	}
@@ -243,7 +262,7 @@ func (h *HugoSites) assemble(bcfg *BuildCfg) error {
 		return nil
 	}
 
-	if err := h.content.AssemblePages(); err != nil {
+	if err := h.getContentMaps().AssemblePages(); err != nil {
 		return err
 	}
 
@@ -314,10 +333,150 @@ func (h *HugoSites) render(config *BuildCfg) error {
 	}
 
 	if !config.SkipRender {
-		if err := h.renderCrossSitesArtifacts(); err != nil {
+		if err := h.renderCrossSitesSitemap(); err != nil {
+			return err
+		}
+		if err := h.renderCrossSitesRobotsTXT(); err != nil {
 			return err
 		}
 	}
 
 	return nil
 }
+
+func (h *HugoSites) postProcess() error {
+	// Make sure to write any build stats to disk first so it's available
+	// to the post processors.
+	if err := h.writeBuildStats(); err != nil {
+		return err
+	}
+
+	var toPostProcess []resource.OriginProvider
+	for _, s := range h.Sites {
+		for _, v := range s.ResourceSpec.PostProcessResources {
+			toPostProcess = append(toPostProcess, v)
+		}
+	}
+
+	if len(toPostProcess) == 0 {
+		return nil
+	}
+
+	workers := para.New(config.GetNumWorkerMultiplier())
+	g, _ := workers.Start(context.Background())
+
+	handleFile := func(filename string) error {
+
+		content, err := afero.ReadFile(h.BaseFs.PublishFs, filename)
+		if err != nil {
+			return err
+		}
+
+		k := 0
+		changed := false
+
+		for {
+			l := bytes.Index(content[k:], []byte(postpub.PostProcessPrefix))
+			if l == -1 {
+				break
+			}
+			m := bytes.Index(content[k+l:], []byte(postpub.PostProcessSuffix)) + len(postpub.PostProcessSuffix)
+
+			low, high := k+l, k+l+m
+
+			field := content[low:high]
+
+			forward := l + m
+
+			for i, r := range toPostProcess {
+				if r == nil {
+					panic(fmt.Sprintf("resource %d to post process is nil", i+1))
+				}
+				v, ok := r.GetFieldString(string(field))
+				if ok {
+					content = append(content[:low], append([]byte(v), content[high:]...)...)
+					changed = true
+					forward = len(v)
+					break
+				}
+			}
+
+			k += forward
+		}
+
+		if changed {
+			return afero.WriteFile(h.BaseFs.PublishFs, filename, content, 0666)
+		}
+
+		return nil
+
+	}
+
+	_ = afero.Walk(h.BaseFs.PublishFs, "", func(path string, info os.FileInfo, err error) error {
+		if info == nil || info.IsDir() {
+			return nil
+		}
+
+		if !strings.HasSuffix(path, "html") {
+			return nil
+		}
+
+		g.Run(func() error {
+			return handleFile(path)
+		})
+
+		return nil
+	})
+
+	// Prepare for a new build.
+	for _, s := range h.Sites {
+		s.ResourceSpec.PostProcessResources = make(map[string]postpub.PostPublishedResource)
+	}
+
+	return g.Wait()
+
+}
+
+type publishStats struct {
+	CSSClasses string `json:"cssClasses"`
+}
+
+func (h *HugoSites) writeBuildStats() error {
+	if !h.ResourceSpec.BuildConfig.WriteStats {
+		return nil
+	}
+
+	htmlElements := &publisher.HTMLElements{}
+	for _, s := range h.Sites {
+		stats := s.publisher.PublishStats()
+		htmlElements.Merge(stats.HTMLElements)
+	}
+
+	htmlElements.Sort()
+
+	stats := publisher.PublishStats{
+		HTMLElements: *htmlElements,
+	}
+
+	js, err := json.MarshalIndent(stats, "", "  ")
+	if err != nil {
+		return err
+	}
+
+	filename := filepath.Join(h.WorkingDir, "hugo_stats.json")
+
+	// Make sure it's always written to the OS fs.
+	if err := afero.WriteFile(hugofs.Os, filename, js, 0666); err != nil {
+		return err
+	}
+
+	// Write to the destination, too, if a mem fs is in play.
+	if h.Fs.Source != hugofs.Os {
+		if err := afero.WriteFile(h.Fs.Destination, filename, js, 0666); err != nil {
+			return err
+		}
+	}
+
+	return nil
+
+}
